/*!
Copyright 2017-2019 Maxim Noltmeer (m.noltmeer@gmail.com)

This file is part of Extern Logic Interpreter.

    Extern Logic Interpreter is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    Extern Logic Interpreter is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with Extern Logic Interpreter.  If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef ELI_INTERFACE_H_INCLUDED
#define ELI_INTERFACE_H_INCLUDED

#ifdef BUILD_DLL
    #define DLL_EXPORT __declspec(dllexport)
#else
    #define DLL_EXPORT __declspec(dllimport)
#endif

typedef void (__cdecl *func_ptr)(void*);   //   -   


class ELI_INTERFACE
{
  public:
    virtual ~ELI_INTERFACE(){};
//   
    virtual void AddFunction(const char *name, const char *params, func_ptr fptr) = 0;
//   
    virtual void DeleteFunction(const char *name) = 0;
// 
    virtual void CallFunction(const char *name) = 0;
//          
//    NULL
    virtual char *GetFunctionResult(const char *name) = 0;
//   
    virtual void SetFunctionResult(const char *name, const char* result) = 0;
//       
    virtual void SetParam(const char *name, const char *new_val) = 0;
//   integer   
    virtual int GetParamToInt(const char *name) = 0;
//   float   
    virtual float GetParamToFloat(const char *name) = 0;
//        
//    NULL
    virtual const char *GetParamToStr(const char *name) = 0;

    virtual const char *GetVersion() = 0;
    virtual const char *ShowVarStack() = 0;
    virtual const char *ShowObjStack() = 0;
    virtual const char *ShowClassStack() = 0;
    virtual const char *ShowProcStack() = 0;
    virtual const char *ShowInfoMessages() = 0;
    virtual const char *RunScript(const char *imptext, const char *parameter, bool log) = 0;
    virtual const char *RunScriptFromFile(const char *filepath, const char *parameter, bool log) = 0;
    virtual const char *ShowFuncStack() = 0;
    virtual const char *ShowParamStack() = 0;
    virtual const char *ShowFragmentStack() = 0;
    virtual const char *GetCurrentFuncName() = 0;
    virtual void SetDebug(bool enable_dbg, bool in_file) = 0;
    virtual bool DebugEnabled() = 0;
};
//--------------------------------------------------------------------------------------------

extern "C"
{
DLL_EXPORT int __cdecl GetELIInterface(ELI_INTERFACE **eInterface);
DLL_EXPORT int __cdecl FreeELIInterface(ELI_INTERFACE **eInterface);
}

typedef int (__cdecl *GETELIINTERFACE)(ELI_INTERFACE **eInterface);
typedef int (__cdecl *FREEELIINTERFACE)(ELI_INTERFACE **eInterface);
#endif // ELI_INTERFACE_H_INCLUDED
